function DIRSPEC = parse_DIRSPEC(DIRSPEC_fpath)
[~, fname, ~] = fileparts(DIRSPEC_fpath);
DIRSPEC.filetime = datenum(fname, 'yyyymmddHHMM');

%% Read the data
fid = fopen(DIRSPEC_fpath);
while true
    tline = fgetl(fid);
    % We shouldn't get to the end before we encounter the "COLUMNS" line
    assert(~isempty(tline));
    if length(tline) > 21 && strcmp(tline(1:21), 'NUMBER OF FREQUENCIES')
        num_freq = sscanf(tline, 'NUMBER OF FREQUENCIES = %d');
    end
    if length(tline) > 17 && strcmp(tline(1:17), 'INITIAL FREQUENCY')
        init_freq = sscanf(tline, 'INITIAL FREQUENCY (Hz) = %f');
    end
    if length(tline) > 17 && strcmp(tline(1:17), 'FREQUENCY SPACING')
        freq_spacing = sscanf(tline, 'FREQUENCY SPACING (Hz) = %f');
    end
    if length(tline) > 26 && strcmp(tline(1:26), 'RESOLVABLE FREQUENCY RANGE')
        DIRSPEC.res_freq_range = sscanf(tline, 'RESOLVABLE FREQUENCY RANGE (Hz) = %f TO %f');
    end
    if length(tline) > 20 && strcmp(tline(1:20), 'NUMBER OF DIRECTIONS')
        num_dirs = sscanf(tline, 'NUMBER OF DIRECTIONS = %d');
    end
    if length(tline) > 23 && strcmp(tline(1:23), 'DIRECTION SPACING (DEG)')
        dir_spacing = sscanf(tline, 'DIRECTION SPACING (DEG) = %f');
    end
    if length(tline) > 4 && strcmp(tline(1:4), 'ROWS')
        % Next line is the data
        break
    end
end

data = textscan(fid, repmat(' %f', [1, num_dirs]));
fclose(fid);

DIRSPEC.spectrum = cell2mat(data);
DIRSPEC.frequencies = init_freq:freq_spacing:freq_spacing*(num_freq - 1);
DIRSPEC.directions = 0:dir_spacing:dir_spacing*(num_dirs - 1);

