function HNE = parse_HNE(HNE_folder)
files = dir(fullfile(HNE_folder, '*.HNE'));
if isempty(files)
    error('parse_HNE:no_HNE_files', ...
        'There are no HNE files in this folder');
end
% Estimate total number of points for the month. Each file has 1382
% points, and there is one file per hour. Use this for preallocation.
est_npoints = numel(files)*24*1382;
HNE.heave = zeros(1, est_npoints, 'single');
HNE.north = zeros(1, est_npoints, 'single');
HNE.east = zeros(1, est_npoints, 'single');
HNE.time = zeros(1, est_npoints, 'double');  % datenums
count = 0;
prog_pct = 5;
pct_thresh = prog_pct;  % For progress indicator
for i = 1:numel(files)
    fpath = fullfile(HNE_folder, files(i).name);
    f = fopen(fpath);
    %%% Get the header data and find the start of the HNE data
    while true
        tline = fgetl(f);
        if isempty(tline)
            error('Never reached "COLUMN 4".');
        end
        if length(tline) > 4 && strcmp(tline(1:4), 'DATE')
            date_str = regexp(tline, 'DATE\s+=\s+(.+)$', 'tokens');
            assert(~isempty(date_str));
            date_str = date_str{1}{1};
            time_base = datenum(date_str, 'yyyy mmm dd HH:MM');
        end
        if length(tline) > 8 && strcmp(tline(1:8), 'COLUMN 4')
            % Next line is data
            break
        end
    end
    %%% Read the data from the file and insert it into the preallocted
    %%% vectors
    data = textscan(f, ' %f %f %f %f');
    ndata = numel(data{1});
    HNE.time(count + 1:count + ndata) = time_base + data{1}./86400;
    HNE.heave(count + 1:count + ndata) = single(data{2});
    HNE.north(count + 1:count + ndata) = single(data{3});
    HNE.east(count + 1:count + ndata) = single(data{4});
    count = count + ndata;
    fclose(f);
    
    % show progress
    pct_complete = (i/numel(files))*100;
    if pct_complete >= pct_thresh
        fprintf('%2.f%% complete.\n', pct_complete);
        pct_thresh = pct_thresh + prog_pct;
    end
end
% Clear any extra entries from vectors
HNE.time(count + 1:end) = [];
HNE.heave(count + 1:end) = [];
HNE.north(count + 1:end) = [];
HNE.east(count + 1:end) = [];

