function MEANDIR = parse_MEANDIR(MEANDIR_fpath)
[~, fname, ~] = fileparts(MEANDIR_fpath);
MEANDIR.filetime = datenum(fname, 'yyyymmddHHMM');

%% Read the data
fid = fopen(MEANDIR_fpath);
while true
    tline = fgetl(fid);
    % We shouldn't get to the end before we encounter the "COLUMN 5" line
    assert(~isempty(tline));
    if length(tline) > 21 && strcmp(tline(1:21), 'NUMBER OF FREQUENCIES')
        num_freq = sscanf(tline, 'NUMBER OF FREQUENCIES = %d');
    end
    if length(tline) > 17 && strcmp(tline(1:17), 'INITIAL FREQUENCY')
        init_freq = sscanf(tline, 'INITIAL FREQUENCY (Hz) = %f');
    end
    if length(tline) > 17 && strcmp(tline(1:17), 'FREQUENCY SPACING')
        freq_spacing = sscanf(tline, 'FREQUENCY SPACING (Hz) = %f');
    end
    if length(tline) > 26 && strcmp(tline(1:26), 'RESOLVABLE FREQUENCY RANGE')
        MEANDIR.res_freq_range = sscanf(tline, 'RESOLVABLE FREQUENCY RANGE (Hz) = %f TO %f');
    end
    if length(tline) > 33 && strcmp(tline(1:33), 'S(f) WEIGHTED MEAN WAVE DIRECTION')
        MEANDIR.weighted_mean_wave_dir = sscanf(tline, 'S(f) WEIGHTED MEAN WAVE DIRECTION = %f');
    end
    if length(tline) > 34 && strcmp(tline(1:34), 'S(f) WEIGHTED MEAN SPREADING WIDTH')
        MEANDIR.weighted_mean_spread_width = sscanf(tline, 'S(f) WEIGHTED MEAN SPREADING WIDTH = %f');
    end
    if length(tline) > 8 && strcmp(tline(1:8), 'COLUMN 4')
        % Next line is the data
        break
    end
end

data = textscan(fid, '%f %f %f %f %f');
fclose(fid);

MEANDIR.frequencies = data{1};
MEANDIR.spectral_density = data{2};
MEANDIR.mean_wave_dir = data{3};
MEANDIR.spreading_width = data{4};


