function UVH = parse_UVH(UVH_folder)
files = dir(fullfile(UVH_folder, '*.UVH'));
if isempty(files)
    error('parse_UVH:no_UVH_files', ...
        'There are no UVH files in this folder');
end
% Estimate total number of points for the month. Each file has 1382
% points, and there is one file per hour. Use this for preallocation.
est_npoints = numel(files)*24*7761;
UVH.heave = zeros(1, est_npoints, 'single');
UVH.vel_N = zeros(1, est_npoints, 'single');
UVH.vel_W = zeros(1, est_npoints, 'single');
UVH.time = zeros(1, est_npoints, 'double');  % datenums
count = 0;
prog_pct = 5;
pct_thresh = prog_pct;  % For progress indicator
for i = 1:numel(files)
    fpath = fullfile(UVH_folder, files(i).name);
    f = fopen(fpath);
    %%% Get the header data and find the start of the UVH data
    while true
        tline = fgetl(f);
        if isempty(tline)
            error('Never reached "COLUMN 4".');
        end
        if length(tline) > 4 && strcmp(tline(1:4), 'DATE')
            date_str = regexp(tline, 'DATE\s+=\s+(.+)$', 'tokens');
            assert(~isempty(date_str));
            date_str = date_str{1}{1};
            time_base = datenum(date_str, 'yyyy mmm dd HH:MM');
        end
        if length(tline) > 8 && strcmp(tline(1:8), 'COLUMN 4')
            % Next line is data
            break
        end
    end
    %%% Read the data from the file and insert it into the preallocted
    %%% vectors
    data = textscan(f, ' %f %f %f %f');
    ndata = numel(data{1});
    UVH.time(count + 1:count + ndata) = time_base + data{1}./86400;
    UVH.heave(count + 1:count + ndata) = single(data{2});
    UVH.vel_N(count + 1:count + ndata) = single(data{3});
    UVH.vel_W(count + 1:count + ndata) = single(data{4});
    count = count + ndata;
    fclose(f);
    
    % show progress
    pct_complete = (i/numel(files))*100;
    if pct_complete >= pct_thresh
        fprintf('%2.f%% complete.\n', pct_complete);
        pct_thresh = pct_thresh + prog_pct;
    end
end
% Clear any extra entries from vectors
UVH.time(count + 1:end) = [];
UVH.heave(count + 1:end) = [];
UVH.vel_N(count + 1:end) = [];
UVH.vel_W(count + 1:end) = [];
